summaryrefslogtreecommitdiff
path: root/src/wasm-stack.h
diff options
context:
space:
mode:
authorHeejin Ahn <aheejin@gmail.com>2024-01-22 19:26:17 -0800
committerGitHub <noreply@github.com>2024-01-22 19:26:17 -0800
commitc23253fa9fb8ab49bc922cf35448ebd3cf0b6789 (patch)
tree0175bf6e0a969da4d6034b70ab7d43cea84c84eb /src/wasm-stack.h
parente06e17e60cfff8a17d00202e208c11c483bedee8 (diff)
downloadbinaryen-c23253fa9fb8ab49bc922cf35448ebd3cf0b6789.tar.gz
binaryen-c23253fa9fb8ab49bc922cf35448ebd3cf0b6789.tar.bz2
binaryen-c23253fa9fb8ab49bc922cf35448ebd3cf0b6789.zip
[EH] Support Stack IR for try_table (#6231)
Diffstat (limited to 'src/wasm-stack.h')
-rw-r--r--src/wasm-stack.h30
1 files changed, 16 insertions, 14 deletions
diff --git a/src/wasm-stack.h b/src/wasm-stack.h
index a195f1a84..de8fd8b03 100644
--- a/src/wasm-stack.h
+++ b/src/wasm-stack.h
@@ -60,20 +60,22 @@ public:
StackInst(MixedArena&) {}
enum Op {
- Basic, // an instruction directly corresponding to a non-control-flow
- // Binaryen IR node
- BlockBegin, // the beginning of a block
- BlockEnd, // the ending of a block
- IfBegin, // the beginning of a if
- IfElse, // the else of a if
- IfEnd, // the ending of a if
- LoopBegin, // the beginning of a loop
- LoopEnd, // the ending of a loop
- TryBegin, // the beginning of a try
- Catch, // the catch within a try
- CatchAll, // the catch_all within a try
- Delegate, // the delegate within a try
- TryEnd // the ending of a try
+ Basic, // an instruction directly corresponding to a
+ // non-control-flow Binaryen IR node
+ BlockBegin, // the beginning of a block
+ BlockEnd, // the ending of a block
+ IfBegin, // the beginning of a if
+ IfElse, // the else of a if
+ IfEnd, // the ending of a if
+ LoopBegin, // the beginning of a loop
+ LoopEnd, // the ending of a loop
+ TryBegin, // the beginning of a try
+ Catch, // the catch within a try
+ CatchAll, // the catch_all within a try
+ Delegate, // the delegate within a try
+ TryEnd, // the ending of a try
+ TryTableBegin, // the beginning of a try_table
+ TryTableEnd // the ending of a try_table
} op;
Expression* origin; // the expression this originates from